.. $Id: bugs.rst 1515 2014-03-11 06:05:15Z jemian $

.. _bugs:

==========
Known bugs
==========

* move this list to the **TRAC** site:
  https://subversion.xray.aps.anl.gov/trac/bcdaext/wiki/SpecDomain
* Duplicate ID warnings, for now, ignore them, the warning will be resolved in a future revision
* roles should link to directives, see *example.mac* to illustrate the problem
* fix the signature recognition for roles
* fix the signature handling for roles and directives
* the out-of-source example PNG shows a Python project, should be a SPEC project